"""Auto-merge multiple Alembic heads

Revision ID: b8baabc0df98
Revises: 000001_k8s_deployment, 000002_k8s_deployment_cost
Create Date: 2025-02-21 21:39:20.885129

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = 'b8baabc0df98'
down_revision: Union[str, None] = ('000001_k8s_deployment', '000002_k8s_deployment_cost')
branch_labels: Union[str, Sequence[str], None] = ('merge_heads',)
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    pass


def downgrade() -> None:
    pass



import json
from datetime import datetime
from hape.services.gitlab_service import GitlabService
from hape.services.file_service import FileService
from hape.hape_cli.models.crud_model import Crud
from hape.hape_cli.models.json_model import Json
from hape.hape_cli.models.yaml_model import Yaml
class Playground:

    @classmethod
    def main(self):
        playground = Playground()
        playground.play()
        
    def generate_gitlab_changes_report(self):
        gitlab = GitlabService()
        start_date = datetime(2025, 2, 3)
        end_date = datetime(2025, 2, 5)
        gitlab.generate_csv_changes_in_cicd_repos(
            group_id=178,
            start_date=start_date,
            end_date=end_date,
            output_file="/Users/hazemataya/Desktop/workspace/innodp/playground/test.csv",
            file_regex=r".*values.*.yaml"
        )

    def play(self):
        
        # json_model = Json(model_schema=True)
        # # json_model.load(Crud._model_schema_json)
        # yaml_model = Yaml(model_schema=True)
        
        # json_model.get()
        # print()
        # yaml_model.get()
        
        # valid_types = ["string", "int", "bool", "float", "date", "datetime", "timestamp"]
        # valid_properties = ["nullable", "required", "unique", "primary", "autoincrement", "foreign-key", "index"]
        
        
        
        {
            "k8s-deployment": {
                "id": {"int": ["primary", "autoincrement"]},
                "service-name": {"string": []},
                "pod-cpu": {"string": []},
                "pod-ram": {"string": []},
                "autoscaling": {"bool": []},
                "min-replicas": {"int": ["nullable"]},
                "max-replicas": {"int": ["nullable"]},
                "current-replicas": {"int": []},
            },
            "k8s-deployment-cost": {
                "id": {"int": ["primary", "autoincrement"]},
                "k8s-deployment-id": {"int": ["required", "foreign-key(k8s-deployment.id, on-delete=cascade)"]},
                "pod-cost": {"string": []},
                "number-of-pods": {"int": []},
                "total-cost": {"float": []}
            }
        }
        
        Crud(
            project_name="hape",
            model_name="k8s-deployment",
            schema={
                "k8s-deployment": {
                    "id": {"int": ["primary", "autoincrement"]},
                    "service-name": {"string": []},
                    "pod-cpu": {"string": []},
                    "pod-ram": {"string": []},
                    "autoscaling": {"bool": []},
                    "min-replicas": {"int": ["nullable"]},
                    "max-replicas": {"int": ["nullable"]},
                    "current-replicas": {"int": []},
                }
            }
        ).generate()
        
        Crud(
            project_name="hape",
            model_name="k8s-deployment-cost",
            schema={
                "k8s-deployment-cost": {
                    "id": {"int": ["primary", "autoincrement"]},
                    "k8s-deployment-id": {"int": ["required", "foreign-key(k8s-deployment.id, on-delete=cascade)"]},
                    "pod-cost": {"string": []},
                    "number-of-pods": {"int": []},
                    "total-cost": {"float": []}
                }
            }
        ).generate()
        
        # Playground().save_deployment_cost()
        # Playground().get_all_deployment_costs()
        # Playground().delete_deployment_cost()
        # Playground().delete_all_deployment_cost()
        # Playground().generate_gitlab_changes_report()



from alembic import op
import sqlalchemy as sa

revision = '000001_k8s_deployment'
down_revision = None
branch_labels = None
depends_on = None

def upgrade():
    op.create_table(
        'k8s_deployment',
        sa.Column('id', sa.Integer, primary_key=True, autoincrement=True),
        sa.Column('service_name', sa.String(255), nullable=True),
        sa.Column('pod_cpu', sa.String(255), nullable=True),
        sa.Column('pod_ram', sa.String(255), nullable=True),
        sa.Column('autoscaling', sa.Boolean, nullable=True),
        sa.Column('min_replicas', sa.Integer, nullable=True),
        sa.Column('max_replicas', sa.Integer, nullable=True),
        sa.Column('current_replicas', sa.Integer, nullable=True)
    )

def downgrade():
    op.drop_table('k8s_deployment')


from alembic import op
import sqlalchemy as sa

revision = '000002_k8s_deployment_cost'
down_revision = None
branch_labels = None
depends_on = None

def upgrade():
    op.create_table(
        'k8s_deployment_cost',
        sa.Column('id', sa.Integer, primary_key=True, autoincrement=True),
        sa.Column('k8s_deployment_id', sa.Integer, sa.ForeignKey('k8s_deployment.id', ondelete='CASCADE'), nullable=False),
        sa.Column('pod_cost', sa.String(255), nullable=True),
        sa.Column('number_of_pods', sa.Integer, nullable=True),
        sa.Column('total_cost', sa.Float, nullable=True)
    )

def downgrade():
    op.drop_table('k8s_deployment_cost')